<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_CA">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>À propos de </translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Faire un don</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Contact</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Licence : </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Outil de capture d&apos;écran et d&apos;annotation</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Raccourci</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Capture d’écran</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Inclure le curseur</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Retarder</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Mode de capture</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Afficher l’image dans la fenêtre d’épinglage</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Copier l’image dans le presse-papier</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Téléverser l’image</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Ouvrir le répertoire parent de l’image</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Enregistrer l’image</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Masquer la fenêtre principale</translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Paramètres des actions</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Action</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Image en filigrane requise</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Veuillez ajouter une image en filigrane via Options &gt; Paramètres &gt; Annotateur &gt; Mettre à jour</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Lisser les tracés peints</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Lorsque cette option est activée, le stylo lisse
les trajectoires des marqueurs après la fin du dessin.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Facteur de lissage</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Augmenter le facteur de lissage diminuera la
précision du stylo et du marqueur mais
les rendra plus lisses.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Paramètres d’annotation</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Se souvenir de la sélection de l’outil d’annotation et le charger au démarrage</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Passer à l’outil de sélection après avoir dessiné l’élément</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>Un changement du numéro de début met à jour tous les items numérotés</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>Lorsqu&apos;on désactive cette option, les changements du numéro
de début n&apos;affectent que les nouveaux items et pas les items existants.
La désactivation de cette option permet des numéros dupliqués.</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Couleur du canevas</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>Couleur d&apos;arrière-plan du canevas par défaut pour la zone d&apos;annotation.
Le changement de couleur n&apos;affecte que les nouvelles zones d&apos;annotation.</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Sélectionner l&apos;élément après le dessin</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>Si cette option est activée, l&apos;élément est sélectionné après
après avoir été créé, ce qui permet de modifier les paramètres.</translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Faire une capture d&apos;écran au lancement avec le mode par défaut</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Style de l&apos;application</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Définit le style d&apos;interface et d’interactivité de l’application.
Vous devrez redémarrer knsip pour le prendre en compte.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Paramètres de l’application</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Copier automatiquement les nouvelles captures dans le presse-papier</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Utiliser les onglets</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Le changement nécessite un redémarrage.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Exécuter Ksnip en tant qu&apos;instance unique</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Masquer la barre d&apos;onglet lorsqu&apos;un seul onglet est utilisé.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>Cette option n&apos;autorise à lancer qu&apos;une seule instance ksnip.
Si d&apos;autres instances sont lancées, elles passeront leurs
arguments à la première avant de s&apos;arrêter. Il faut redémarrer
toutes les instances pour activer ou désactiver cette option.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Mémoriser la position de la fenêtre principale lors du déplacement et la charger au démarrage</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Cacher automatiquement les onglets</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Masquer les panneaux automatiquement</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>Masquer au démarrage la barre d’outils et les outils d’annotation.
La visibilité du panneau d’outils peut être basculée avec la touche TAB.</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Redimensionnement automatique en fonction du contenu</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Redimensionner automatiquement la fenêtre principale pour l&apos;adapter à l&apos;image du contenu.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>Activer le débogage</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>Active la sortie de débogage écrite sur la console.
Le changement nécessite le redémarrage de ksnip pour prendre effet.</translation>
    </message>
    <message>
        <source>Resize to content delay</source>
        <translation>Redimensionnement en fonction du retard du contenu</translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation>Le redimensionnement du contenu est retardé pour permettre au gestionnaire de fenêtres de recevoir le nouveau contenu.
le nouveau contenu. Dans le cas où la fenêtre principale n&apos;est pas ajustée correctement au nouveau contenu, l&apos;augmentation de ce délai peut améliorer le comportement.
au nouveau contenu, l&apos;augmentation de ce délai peut améliorer le comportement.</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Contributeurs :</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Traduction en espagnol</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Traduction en néérlandais</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Traduction en russe</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Traduction en norvégien</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Traduction en français</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Traduction en polonais</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Support Snap &amp; Flatpak</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>Les auteurs :</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Alerte - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>La capture %1%2%3 a été modifiée.
Voulez-vous l&apos;enregistrer?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Tracer un rectangle avec la souris</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Capture en plein écran, incluant tous les moniteurs</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Capture de l&apos;écran où se trouve la souris</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Capturer la fenêtre active</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Capturer ce qui est actuellement sous le curseur de la souris</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Fait une capture d&apos;écran de la dernière zone sélectionnée</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>Utilise le portail de capture d&apos;écran pour les captures</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Communauté</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Signalements d&apos;erreurs</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>Si vous avez des questions générales, des idées ou si vous voulez simplement parler de ksnip,&lt;br/&gt;veuillez rejoindre notre %1 ou notre %2 serveur.</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>Veuillez utiliser %1 pour signaler les bogues.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>Impossible de copier dans le presse-papier</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>Échec de la copie dans le presse-papier en tant qu’image encodée en base64.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>Copié dans le presse-papier</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Copié dans le presse-papier en tant qu’image encodée en base64.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Supprimer l&apos;image</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>L&apos;élément «&#xa0;%1&#xa0;» va être supprimer.
Voulez-vous continuer?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Les dons sont toujours les bienvenus</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Dons</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip est un projet de logiciel libre copylefté non rentable, et &lt;br/&gt;a toujours certains coûts qui doivent être couverts,&lt;br/&gt;comme les coûts de domaine ou les coûts de matériel pour la prise en charge multiplateforme.</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>Si vous voulez aider ou simplement apprécier le travail accompli&lt;br/&gt;en offrant aux développeurs une bière ou un café, vous pouvez le faire %1here%2.</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>Devenir un sponsor de GitHub?</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>Également possible, %1here%2.</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Ajouter de nouvelles actions en cliquant sur le bouton de l&apos;onglet «&#xa0;Ajouter&#xa0;».</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Zone rectangulaire</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Dernière zone rectangulaire</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Plein Écran (tous les moniteurs)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Écran actuel</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Fenêtre active</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Fenêtre sous le curseur</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Portail de capture d&apos;écran</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>Forcer le téléversement anonyme.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>Téléverseur FTP</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Téléversement réussi</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Impossible de sauvegarder une image temporaire pour le téléversement.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Impossible de démarrer le processus, vérifiez le chemin et les permissions.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>L’application a planté</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>L’application a mis trop de temps à répondre.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Erreur de lecture de l’application.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Erreur d’écriture de l’application.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Erreur Web, vérifier la sortie de la console.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Échec de téléversement</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>Le script a écrit sur StdErr.</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>Le téléversement FTP s&apos;est terminé avec succès.</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Erreur inconnue.</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>Erreur de connexion.</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>Erreur d&apos;autorisation.</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation>Le script de téléversement %1 s&apos;est terminé avec succès.</translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation>Téléversé sur %1</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Activer les raccourcis globaux</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Capturer zone rectangulaire</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Capturer tout l&apos;écran</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Capturer l&apos;écran actif</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Capturer la fenêtre active</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Capturer la fenêtre sous le curseur</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Raccourcis globaux</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Capturer la dernière zone rectangulaire</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Capturer par le portail</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>Les HotKeys ne sont actuellement prises en charge que pour Windows et X11.
La désactivation de cette option rend également les raccourcis d&apos;action ksnip uniquement.</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Inclure le curseur de la souris lors d&apos;une capture d&apos;écran</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Le curseur de la souris doit-il être visible
les captures d’écran.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Captureur d&apos;image</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>L&apos;implémentation de Generic Wayland
qui utilise XDG-DESKTOP-PORTAL gère les
changements d&apos;échelle différemment. Cette
option détermine le changement d&apos;échelle
en cours pour l&apos;appliquer à la capture ksnip.</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>GNOME et KDE Plasma prennent en charge leur 
propre Wayland et les captures Generic
XDG-DESKTOP-PORTAL. Cette option force KDE
Plasma et GNOME à utiliser les captures
 XDG-DESKTOP-PORTAL. Redémarrage requis.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>Afficher la fenêtre principale après la capture d&apos;écran</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Cacher la fenêtre principale pendant la capture</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Cacher la fenêtre principale pendant une nouvelle capture.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>Afficher la fenêtre principale après avoir créé une nouvelle capture d&apos;écran
lorsque la fenêtre principale a été masquée ou réduite.</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation>Capture d&apos;écran de Force Generic Wayland (xdg-desktop-portal)</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation>Captures d&apos;écran de Scale Generic Wayland (xdg-desktop-portal)</translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Historique Imgur</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Horodatage</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Lien</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Supprimer le lien</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>Téléversement sur imgur.com terminé!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Nouveau jeton reçu, nouvelle tentative de téléversement…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Jeton Imgur expiré, demande de renouvellement…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Anonymiser le téléversement</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Toujours copier le lien Imgur dans le presse-papier</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>ID Client</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Client secret</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>NIP</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Entrez le NIP Imgur pour l&apos;échanger contre un jeton.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Obtenir un NIP</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Obtenir un token</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Historique Imgur</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Envoyer sur Imgur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>En attente d&apos;imgur.com…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Jeton imgur.com mis à jour avec succès.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Erreur de mise à jour du token Imgur.com.</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Après téléversement, ouvrir le lien imgur avec le navigateur par défaut</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Relier directement l&apos;image</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>URL de base&#xa0;:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>L’URL de base sera utilisée pour communiquer avec Imgur.
La modifier nécessite un redémarrage.</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Effacer les jetons</translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>Impossible d’ouvrir l’image</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>Impossible d’ouvrir l’image à partir du chemin %1</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Délai en secondes entre le déclenchement
et la capture de l&apos;écran.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Enregistrer la capture d&apos;écran sur le disque</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Copier la capture d&apos;écran dans le presse-papier</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Outils</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Rétablir</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Découper</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Découper la capture d&apos;écran</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>Non enregistré</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Téléverser</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Ouvre l&apos;interface de l&apos;imprimante et affiche les options d&apos;impression</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Aperçu avant impression</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Ouvre la boîte de dialogue Aperçu avant impression où l&apos;orientation de l&apos;image peut être modifiée</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Redimensionner</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;À propos</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>É&amp;dition</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Options</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Ajouter un filigrane</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Ajout d&apos;un filigrane à l&apos;image capturée. Plusieurs filigranes peuvent être ajoutés.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>Impossible d&apos;afficher l&apos;image</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Enregistrer sous…</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Coller l&apos;intégration</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Épingler</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>Épingler la capture au premier plan dans une fenêtre sans bords</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>Une image est attendue mais aucune fournie.</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Chemin de copie</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Ouvrir le dossier</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Afficher</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Ouvrir les images</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Afficher le panneau d&apos;outils</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Cacher le panneau d&apos;outils</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>Copie en tant qu’URI de données</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>Ouvrir &amp;Récent</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Modifier le canevas</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation>Téléverser la capture du déclencheur vers une source externe</translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation>Copier la capture du déclencheur dans le presse-papier du système</translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Image à l&apos;échelle</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Pivoter</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Pivoter l&apos;image</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Actions</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Fichiers d&apos;images</translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Enregistrer sous</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Ouvrir le dossier</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Copier le chemin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Capture</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Fermer les autres</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tout fermer</translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation>Épingler la fenêtre %1</translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>Image renommée</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Échec du renommage de l&apos;image</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Renommer l&apos;image</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Nouveau nom de fichier :</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation>L&apos;image a été renommée avec succès en %1</translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation>Échec du renommage de l&apos;image en %1</translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Enregistrer sous</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Image sauvegardée</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Échec de la sauvegarde de l&apos;image</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Fichiers d&apos;images</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Enregistré dans %1</translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation>Échec de la sauvegarde de l&apos;image dans %1</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Enregistrer automatiquement les nouvelles captures dans l&apos;emplacement par défaut</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>Proposer d&apos;enregistrer en cas d&apos;abandon de modifications non enregistrées</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Se souvenir du dernier emplacement de sauvegarde</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>Proposer le dernier emplacement utilisé pour l&apos;enregistrement
plutôt que celui défini ci-dessous.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>Répertoire d&apos;enregistrement et nom du fichier</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>Les formats supportés sont JPG, PNG et BMP. Si aucun format n’est spécifié, PNG sera utilisé par défaut.
Le nom du fichier peut contenir les jokers suivants&#xa0;:
- $Y : année, $M : mois, $D : jour, $h : heure, $m : minutes, $s : secondes, $T : temps au format «&#xa0;hhmmss&#xa0;».
- Plusieurs caractères # permettent de numéroter. Par exemple : #### donnera 0001 puis 0002 à la prochaine capture.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Parcourir</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Paramètres d&apos;enregistrement</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Répertoire d&apos;enregistrement des captures</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Facteur</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Qualité d&apos;enregistrement</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>Préciser 0 pour des fichiers compressés légers, 100 pour des fichiers lourds
non compressés. Certains format ne prennent pas en charge l&apos;intervalle en
entier comme c&apos;est le cas pour le JPEG.</translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Copier la sortie du script vers le presse-papier</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Script :</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>Chemin vers le script qui sera utilisé pour le téléversement. Le script sera appelé
avec le chemin vers une image temporaire au format PNG comme unique argument.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Parcourir</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Script d&apos;envoi</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Sélectionner le script d&apos;envoi</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>Arrêter quand le script d&apos;envoi écrit sur StdErr</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>L&apos;envoi sera noté comme échoué si le script a écrit sur StdErr.
Si cette case n&apos;est pas cochée, les erreurs du script passeront inaperçues.</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtre :</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>Expression rationnelle (RegEx). Seules les lignes correspondant à la RegEx seront
copiées dans le presse-papier. Si aucun filtre n&apos;est défini, toutes les lignes seront copiées.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Captureur d&apos;image</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Envoyer sur Imgur</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Application</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Annotation</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Raccourcis clavier</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Envoi sur un serveur</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Script d&apos;envoi</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>Enregistrement</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Autocollants</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Zone de capture</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Icône de la barre des tâches</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Filigrane</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Actions</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>Téléverseur FTP</translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>Ajuster la taille du rectangle sélectionné en utilisant les poignées ou déplacez-le en glissant la sélection.</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>Utilisez les touches fléchées pour déplacer la sélection.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>Utiliser les touches flèches en pressant CTRL pour déplacer la poignée en haut à gauche.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>Utiliser les touches flèches en pressant ALT pour déplacer la poignée en bas à droite.</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
        <translation>Confirmer la sélection en pressant ENTRÉE/RETOUR ou avorter en pressant ESC.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Ce message peut être désactivé via les préférences.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>Cliquez et faites glisser pour sélectionner une zone rectangulaire ou appuyez sur ÉCHAP pour quitter.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>Maintenez la touche CTRL enfoncée pour redimensionner la sélection après avoir fait une sélection.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>Maintenez la touche CTRL enfoncée pour empêcher le redimensionnement après avoir effectué une sélection.</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>L’opération sera annulée après 60 secondes si aucune sélection n’est effectuée.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Ce message peut être désactivé via les préférences.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Figer l’image lors de la capture</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>Pour figer l&apos;arrière-plan lors de la sélection
rectangulaire. Cela affecte aussi le comportement
des captures avec délai.
Activé, la durée est avant l&apos;affichage de la zone
de sélection. Désactivé, la durée est après.
Cette fonctionnalité n&apos;est jamais
active sur Wayland mais toujours sur MacOS.</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>Afficher la loupe sur la zone de capture</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>Afficher une loupe qui grossit le fond d’écran.
Cette option ne fonctionne que si «&#xa0;Figer l’image
avant capture&#xa0;» est activé.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>Afficher les règles de la zone de capture</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>Afficher des lignes horizontales et verticales
depuis les bords de l&apos;écran jusqu&apos;au pointeur pour aider au cadrage.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>Afficher les informations sur la position et la taille de la zone de capture</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>Lorsque le bouton gauche de la souris n&apos;est pas enfoncé,
la position s&apos;affiche, lorsque le bouton de la souris est
enfoncé, la taille de la zone sélectionnée est indiquée à
gauche et au-dessus de la zone capturée.</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>Autoriser le redimensionnement de la sélection de la zone rectangulaire par défaut</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation>Lorsque l&apos;option est activée, après avoir sélectionné une
zone rectangulaire, celle-ci peut être redimensionnée.
Le redimensionnement de la sélection peut être confirmé
en appuyant sur la touche retour.</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation>Afficher le texte d’informations sur la zone de capture</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>Couleur du curseur de la zone de capture</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation>Définit la couleur du curseur de la zone de capture.</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>Épaisseur du curseur de la zone de capture</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation>Règle l’épaisseur du curseur de la zone de capture.</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Zone de capture</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>Couleur d&apos;ornement de la zone de capture</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation>Définit la couleur de tous les éléments
d’ornement sur la zone de capture.</translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Transparence de la zone de capture</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>Alpha pour la région en dehors de la zone de capture.
Une petite valeur est plus transparente.</translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>Monter</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Descendre</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Utiliser les stickers par défaut</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Paramètres des stickers</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Images vectorielles (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>Ajouter des Stickers</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Montrer l&apos;éditeur</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>Utiliser l&apos;icône de la barre de tâches</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>Si activé, ajoute une icône dans la barre des tâches si le système d’exploitation le permet.
Le changement nécessite un redémarrage.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Réduire vers la barre des tâches</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Démarrer en miniature dans la barre des tâches</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Fermer vers la barre des tâches</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>Afficher l’éditeur</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Capture</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Action par défaut de l’icône de la barre des tâches</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>Action par défaut déclenchée par un clic gauche sur l’icône dans la barre des tâches.</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Paramètres de l’icône de la barre des tâches</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>Utiliser un service de notification spécifique à la plateforme</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>Lorsque cette option est activée, elle essaiera d&apos;utiliser un service de notification spécifique à la plateforme lorsqu&apos;il existe.
spécifique à la plateforme lorsqu&apos;il existe. Le changement nécessite un redémarrage pour prendre effet.</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation>Afficher les notifications de l&apos;icône de la barre d&apos;état système</translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Sélectionner l&apos;image</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Fichiers d&apos;images</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Un script d&apos;envoi est nécessaire</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Veuillez ajouter un script d&apos;envoi dans Options &gt; Paramètres &gt; Script d&apos;envoi</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Envoi de la capture</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>La capture va être téléversée sur un serveur externe. Souhaitez-vous continuer?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>Demander une confirmation avant de téléverser</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Méthode d&apos;envoi :</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Script</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Envoi sur un serveur</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Compiler</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Dépendances :</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>Image en filigrane</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Mettre à jour</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Pivoter le filigrane</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>Si activé, le filigrane sera ajouté avec une rotation de 45°</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Paramètres des filigranes</translation>
    </message>
</context>
</TS>
